---
project: Cratermaker
author: David A. Minton
summary: High performance Fortran functions used by the Cratermaker project via ISO_C_BINDING interfaces and Cython.
project_github: https://github.com/profminton/cratermaker
project_download: https://github.com/profminton/cratermaker/releases
project_website: https://cratermaker.readthedocs.io
github: https://github.com/profminton/
src_dir: src
output_dir: ./docs/_static/fortran_docs
source: true
graph: true
sort: alpha
print_creation_date: true
extra_mods: iso_c_binding:https://gcc.gnu.org/onlinedocs/gfortran/ISO_005fC_005fBINDING.html
creation_date: %Y-%m-%d %H:%M %z
md_extensions: markdown.extensions.toc
               markdown.extensions.smarty
---

This is the documentation for the Fortran components of Cratermaker
